require(dplyr)
require(classInt)
require(fields)
require(foreign)
require(rgeos)
require(maptools)
require(tidyr)
require(plotrix)
require(RColorBrewer)
setwd('~/Desktop/projects/wkenya/uganda/maps_2016/')  #should be changed to wherever data file is

#read in field-level data combined with satellite measures extracted for those fields
comb = read.csv('maps2016.dataforrep.csv')

#note that 6 different sentinel 2 VIs are provided for each date
#they correspond (in order) to 
#  gcvi (calculated at pixel level then averaged), e.g. DOY_mean_151
#  gcvi (calculated using field averages of bands), e.g. DOY_mean_151.1
#  mtci (calculated using field averages of bands),e.g. DOY_mean_151.2
#  ndvi (calculated at pixel level then averaged), e.g. DOY_mean_151.3
#  red edge ndvi (using r705) (calculated using field averages of bands),e.g. DOY_mean_151.4
#  red edge ndvi (using r740) (calculated using field averages of bands),e.g. DOY_mean_151.5
#  mtci (calculated at pixel level then averaged), e.g. DOY_mean_151.6

############
#FIGURE 2
#YIELD DISTRIBUTIONS AND CORRELATIONS
############

quartz(w=10,h=6)
par(mfrow=c(1,2),lwd=3,mar=c(5,4,1,1),cex.axis=1.2,cex.lab=1.2)
layout(rbind(1:2,c(1,3)))
cols=brewer.pal(3,'Set1')
xlim=c(0,6)
ylim=c(0,1e0)
plot(density(comb$sr_yield,from=0,na.rm=T),lwd=3,xlim=xlim,ylim=ylim,xlab='Yield (t/ha)',ylab='Density',main='',col=cols[1])
lines(density(comb$cc_yield,from=0,na.rm=T),lwd=3,col=cols[2])
lines(density(comb$fullplot_yield,from=0,na.rm=T),lwd=3,col=cols[3])
legend('topright',bty='n',leg=c('Self-Report (SR)','Crop Cut Harvest (CC)','Full Plot harvest (FP)'),lwd=3,col=cols,cex=1.5)
legend('topleft',bty='n',leg='(a)',cex=1.5,adj=1)
means=c(mean(comb$sr_yield,na.rm=T),mean(comb$cc_yield,na.rm=T),mean(comb$fullplot_yield,na.rm=T))
medians=c(median(comb$sr_yield,na.rm=T),median(comb$cc_yield,na.rm=T),median(comb$fullplot_yield,na.rm=T))
for (i in 1:3) rug(means[i],ticksize = .1,side = 1,col = cols[i],lwd=2)


ind = which(comb$plot_area_GPS < 0.05)
xlim=c(0,5)
scatxy = function(x,y,ind,xlab='',ylab=''){
  plot(x[-ind],y[-ind],xlab=xlab,
       ylab=ylab,xlim=xlim,ylim=xlim)
  points(x[ind],y[ind],col=1,pch=1)
  cors=round(c(cor(x,y,use='p'),cor(x[-ind],y[-ind],use='p')),2)
  legend('bottomright',leg=paste0(c('All Fields, r = ','Fields >= 0.05 ha, r = '),cors),title = expression(underline("Correlation")),
         text.col=c(1,1),title.adj=0.5,bty='n',xjust=0,inset=.0)
}
scatxy(comb$cc_yield,comb$sr_yield,ind,xlab='CC Yield (Mg/ha)',
     ylab='SR Yield (Mg/ha)')
legend('topright',leg=c(' < 0.05 ha',' >= 0.05 ha'),title=expression(underline('Field Size')),
       pch=c(1,19),bty='y',xjust=0,title.adj=0.5,inset=.02)
legend('topleft',bty='n',leg='(b)',cex=1.5,adj=1)
scatxy(comb$cc_yield,comb$fullplot_yield,ind,xlab='CC Yield (Mg/ha)',
     ylab='FP Yield (Mg/ha)')
legend('topleft',bty='n',leg='(c)',cex=1.5,adj=1)

dev.print(png,paste0('yielddistandscatter.png'),width=1000,height=600)
dev.print(pdf,paste0('yielddistandscatter.pdf'),width=10,height=6)

############
#FIGURE 3 - SHOWING VI CORRELATIONS (also Fig A2 to show results by image date)
############

plot.corbysize=function(comb,formulas,modnames,use,athresh=seq(0,.2,.05),cols=1,ltys=1){
  nform = length(formulas)
  temp=c()
  for (minarea in athresh){
    ind=which(comb$plot_area_GPS >= minarea & use == T)
    for (form.i in 1:nform) {
      modtemp=lm(formulas[[form.i]],data=comb[ind,])
      temp=rbind(temp,c(model=form.i,minarea=minarea,unlist(summary(modtemp)[c('r.squared','adj.r.squared','df')])))
    }
  }
  temp=data.frame(temp)
  temp2 = reshape(temp[,1:3],idvar="model",timevar="minarea",v.names='r.squared',direction='wide')
  matplot(athresh,t(temp2[,-1]),type='o',pch=19,lwd=2,lty=ltys,col=cols,xlab='Min field size (ha)',
          ylab=expression(paste('adjusted R'^2)),ylim=c(-.05,1))
  sampsize = (temp$df2+temp$df1)[temp$model==1]
  text(athresh,0,sampsize)
  #text(athresh,0,paste0(c('n = \n',rep('\n',length(sampsize)-1)),sampsize))
  #points(temp$minarea,temp$r.squared,cex=rescale(temp$df2+temp$df1,c(.3,3)),col=gray(.8))
  legend('topright',col=cols,lwd=2,lty=ltys,leg=modnames,bty='n',cex=1.3)
  temp
}

yvars = c('sr_yield','cc_yield','fullplot_yield')
#Fig 3
#a version that fits model using both dates
hold2=data.frame()
athresh=seq(0,.1,by=.025)
#for (doy in c(151,171)){
for (yvar in yvars){
  xvars1 = paste0('DOY_mean_',151,c('.3','','.6','.4','.5'))
  xvars2 = paste0('DOY_mean_',171,c('.3','','.6','.4','.5'))
  modnames = paste0('DOY both',c(' NDVI',' GCVI',' MTCI',' NDVI705',' NDVI740'))
  formulas = list()
  for (i in 1:length(modnames)) formulas[[i]]=as.formula(paste0(yvar,'~',xvars1[i],' + ',xvars2[i]))
  nform = length(formulas)
  cols=brewer.pal(nform,'Set1')
  ltys=1
  use = (comb$purestand == 1)
  temp = plot.corbysize(comb,formulas,modnames,use,athresh,cols,ltys)
  # legend('topleft',labs[k],cex=1.3,bty='n')
  # k=k+1
  # print(paste(yvar,doy));print(temp)
  hold2=rbind(hold2,data.frame(yvar=yvar,doy = 'both',temp))
  #  }
}
hold2$nsamp = hold2$df1 + hold2$df2
hold2$xlab = c(' NDVI',' GCVI',' MTCI',' NDVI705',' NDVI740')[hold2$model]
hold2$xy = paste(hold2$yvar,hold2$xlab)
pd = hold2 %>% filter(model %in% c(1,2,3) & minarea %in% athresh)
temp2 = reshape(pd[,c('minarea',"adj.r.squared",'xy')],idvar="xy",timevar="minarea",v.names='adj.r.squared',direction='wide')
temp3 = reshape(pd[,c('minarea',"nsamp",'xy')],idvar="xy",timevar="minarea",v.names='nsamp',direction='wide')
cols=rep(brewer.pal(3,'Set1'),each=3)
ltys = rep(3:1,3)
quartz(w=6,h=5)
par(mar=c(5,5,1,1))
matplot(athresh,t(temp2[,-1]),type='o',pch=19,lwd=2,lty=ltys,col=cols,xlab='Min field size (ha)',
        ylab=expression(paste('adjusted R'^2)),ylim=c(-.05,1))
legend('top',col=brewer.pal(3,'Set1'),leg=c('SR','CC','FP'),title='Yield Measure',bty='n',lwd=2,cex=1.2)
legend('topright',col=1,leg=c('NDVI','GCVI','MTCI'),title='Veg. Index',bty='n',lwd=2,lty=3:1,cex=1.2)
dev.print(png,paste0('multvi1panel.png'),width=600,height=500)
dev.print(pdf,paste0('multvi1panel.pdf'),width=6,height=5)

#Fig A2 - version that focuses less on VIs and more on different yield measures
hold=data.frame()
athresh=seq(0,.1,by=.025)
for (doy in c(151,171)){
  for (yvar in yvars){
    xvars = paste0('DOY_mean_',doy,c('.3','','.2','.4','.5'))
    modnames = paste0('DOY ',doy,c(' NDVI',' GCVI',' MTCI',' NDVI705',' NDVI740'))
    formulas = list()
    for (i in 1:length(modnames)) formulas[[i]]=as.formula(paste0(yvar,'~',xvars[i]))
    nform = length(formulas)
    cols=brewer.pal(nform,'Set1')
    ltys=1
    use = (comb$purestand == 1)
    temp = plot.corbysize(comb,formulas,modnames,use,athresh,cols,ltys)
    # legend('topleft',labs[k],cex=1.3,bty='n')
    # k=k+1
    # print(paste(yvar,doy));print(temp)
    hold=rbind(hold,data.frame(yvar=yvar,doy = doy,temp))
  }
}
hold$nsamp = hold$df1 + hold$df2
hold$xlab = c(' NDVI',' GCVI',' MTCI',' NDVI705',' NDVI740')[hold$model]
hold$xy = paste(hold$yvar,hold$xlab)
quartz(w=12,h=5)
par(mfrow=c(1,2),mar=c(5,5,1,1),cex.lab=1.3,cex.axis=1.3)
cols=rep(brewer.pal(3,'Set1'),each=3)
ltys = rep(3:1,3)
pd = hold %>% filter(doy == 151 & model %in% c(1,2,3) & minarea %in% athresh)
temp2 = reshape(pd[,c('minarea',"adj.r.squared",'xy')],idvar="xy",timevar="minarea",v.names='adj.r.squared',direction='wide')
temp3 = reshape(pd[,c('minarea',"nsamp",'xy')],idvar="xy",timevar="minarea",v.names='nsamp',direction='wide')

matplot(athresh,t(temp2[,-1]),type='o',pch=19,lwd=2,lty=ltys,col=cols,xlab='Min field size (ha)',
        ylab=expression(paste('adjusted R'^2)),ylim=c(-.05,1))
legend('topleft',leg='(a) May 30',bty='n',cex=1.4,adj=.2)
legend('top',col=brewer.pal(3,'Set1'),leg=c('SR','CC','FP'),title='Yield Measure',bty='n',lwd=2,cex=1.2)
legend('topright',col=1,leg=c('NDVI','GCVI','MTCI'),title='Veg. Index',bty='n',lwd=2,lty=3:1,cex=1.2)
pd = hold %>% filter(doy == 171 & model %in% c(1,2,3) & minarea %in% athresh)
temp2 = reshape(pd[,c('minarea',"adj.r.squared",'xy')],idvar="xy",timevar="minarea",v.names='adj.r.squared',direction='wide')
temp3 = reshape(pd[,c('minarea',"nsamp",'xy')],idvar="xy",timevar="minarea",v.names='nsamp',direction='wide')
matplot(athresh,t(temp2[,-1]),type='o',pch=19,lwd=2,lty=ltys,col=cols,xlab='Min field size (ha)',
        ylab=expression(paste('adjusted R'^2)),ylim=c(-.05,1))
#cex=plotrix::rescale(t(temp3[,-1]),c(.5,2)) #makes plot too confusing. just add to caption
legend('topleft',leg='(b) June 19',bty='n',cex=1.4,adj=.2)
legend('top',col=brewer.pal(3,'Set1'),leg=c('SR','CC','FP'),title='Yield Measure',bty='n',lwd=2,cex=1.2)
legend('topright',col=1,leg=c('NDVI','GCVI','MTCI'),title='Veg. Index',bty='n',lwd=2,lty=3:1,cex=1.2)
dev.print(png,paste0('multvi2panel.png'),width=1200,height=500)
dev.print(pdf,paste0('multvi2panel.pdf'),width=12,height=5)

#################
#FIG 4 - CALIBRATED AND SCYM PERFORMANCE FOR > .1HA PURESTAND
#################
ind=which(comb$plot_area_GPS >= .1 & (comb$purestand == 1))
satfit1 = lm(fullplot_yield ~ DOY_mean_151.6 + DOY_mean_171.6,data=comb[ind,])
satfit2 = lm(cc_yield ~ DOY_mean_151.6 + DOY_mean_171.6,data=comb[ind,])
satfit3 = lm(sr_yield ~ DOY_mean_151.6 + DOY_mean_171.6,data=comb[ind,])
#summary(satfit1)
comb$satpred1 = predict(satfit1,comb)
comb$satpred2 = predict(satfit2,comb)
comb$satpred3 = predict(satfit3,comb)
scymcoefs=c(-0.448036944929729,0.284536531969379,0.270951734185058)
comb$scymyield = 1e0*(scymcoefs[1] + scymcoefs[2]*comb$DOY_mean_151.2 + scymcoefs[3]*comb$DOY_mean_171.2)

quartz(w=18,h=5)
par(mfrow=c(1,3),lwd=3,mar=c(5,4.5,1,1),cex.lab=1.5,cex.axis=1.5,cex=1.5)
xlim=ylim=c(0,4)
ind=which(comb$plot_area_GPS >= .1 & (comb$purestand == 1))
plot(comb$satpred1[ind],comb$fullplot_yield[ind],
     xlab='RS_CAL yield (Mg/ha)',ylab='FP yield (Mg/ha)',xlim=xlim,ylim=ylim); 
temp0 = lm(fullplot_yield~satpred1,data=comb[ind,])
abline(c(0,1));abline(temp0$coef,lty=2)
#legend('topleft',paste0('(a) Full Plot Calibrated, R2 = ',round(summary(temp0)$r.sq,2)),bty='n')
r2=round(summary(temp0)$r.sq,2)
mylabel = bquote(italic(R)^2 == .(format(r2, digits = 2)))
text(0,3.9,'(a) Full Plot Calibrated',cex=1.1,pos=4)
text(0,3.5,mylabel,cex=1.1,pos=4)

plot(comb$satpred2[ind],comb$cc_yield[ind],
     xlab='RS_CAL_CC yield (Mg/ha)',ylab='CC yield (Mg/ha)',xlim=xlim,ylim=ylim); 
temp1 = lm(cc_yield~satpred2,data=comb[ind,])
abline(c(0,1));abline(temp1$coef,lty=2)
#legend('topleft',paste0('(b) Crop Cut Calibrated, R2 = ',round(summary(temp1)$r.sq,2)),bty='n')
r2=round(summary(temp1)$r.sq,2)
mylabel = bquote(italic(R)^2 == .(format(r2, digits = 2)))
text(0,3.9,'(b) Crop Cut Calibrated',cex=1.1,pos=4)
text(0,3.5,mylabel,cex=1.1,pos=4)

plot(comb$scymyield[ind],comb$fullplot_yield[ind],
     xlab='RS_SCYM yield (Mg/ha)',ylab='FP yield (Mg/ha)',xlim=xlim,ylim=ylim);
temp2 = lm(fullplot_yield~scymyield,data=comb[ind,])
abline(c(0,1));abline(temp2$coef,lty=2)
#legend('topleft',paste0('(c) Uncalibrated (SCYM), ',expression(paste('R'^2)),' = ',round(summary(temp2)$r.sq,2)),bty='n')
r2=round(summary(temp2)$r.sq,2)
mylabel = bquote(italic(R)^2 == .(format(r2, digits = 2)))
text(0,3.9,'(c) Uncalibrated (SCYM)',cex=1.1,pos=4)
text(0,3.5,mylabel,cex=1.1,pos=4)

dev.print(png,paste0('modfits.png'),width=1800,height=500)
dev.print(pdf,paste0('modfits.pdf'),width=18,height=5)

#Fig 5 - out-of-sample skill as function of different training samples

cvr2 = function(modfit,k=5){
  mod=modfit$model
  names(mod)[1]='y'
  folds = sample(rep(c(1:k),length.out=nrow(mod)),size=nrow(mod))
  sapply(1:k,function(i) {
    ii = which(folds == i)
    tmp = mod[ii,]
    tmpmod = lm(y~.,tmp)
    predy = predict(tmpmod,mod[-ii,])
    return(c(cor(predy,mod[-ii,1])^2,
             sqrt(mean((predy - mod[-ii,1])^2))))})
}

fpcv = cvr2(satfit1,k=5)
cccv = cvr2(satfit2,k=5)
apply(fpcv,1,mean)
apply(cccv,1,mean)

#get mean running 1000 times
fpcvs = sapply(1:1000,function(x) apply(cvr2(satfit1,k=5),1,mean))
apply(fpcvs,1,mean)
cccvs = sapply(1:1000,function(x) apply(cvr2(satfit2,k=5),1,mean))
apply(cccvs,1,mean)

#slightly different: compute outofsample rmse and r2 when using subset of data to calibrate
#always test against the fullplot yields (using all FP yields to test for simplicity, rather than just
#the ones that were not used to train the model)
mods=list(satfit1$model,satfit2$model,satfit3$model)
names(mods[[1]])[1]=names(mods[[2]])[1]=names(mods[[3]])[1]='y'

oos_rmse = function(nfield=20){
  samps = list(sample(1:nrow(mods[[1]]),nfield,replace = F),
  sample(1:nrow(mods[[2]]),nfield,replace = F),sample(1:nrow(mods[[3]]),nfield,replace = F))
  out=c()
  for (modi in 1:3){
    tmpmod = lm(y~.,mods[[modi]][samps[[modi]],])
    predy = predict(tmpmod,mods[[1]])
    truey = mods[[1]][,1]
    perf = c(cor(predy,truey)^2,
      sqrt(mean((predy - truey)^2)))
    out = cbind(out,perf)
  }
  return(out)
}

#for each number of training, find rmse and r2 nrun times and then average
nfields = c(seq(4,10,2),seq(15,25,by=5))
nrun=5e2
errbytrainsize = sapply(nfields,function(x) {
  out=c()
  for (i in 1:nrun) out=rbind(out,as.numeric(oos_rmse(nfield=x)))
  return(c(apply(out,2,mean),apply(out,2,quantile,.05),apply(out,2,quantile,.95)))})

quartz(w=12,h=5)
par(mfrow=c(1,2),mar=c(5,5,1,1),cex.lab=1.3,cex.axis=1.3)
cols=brewer.pal(3,'Set1')
ylim=c(0,2)
lwd=3
plot(nfields,errbytrainsize[2,],xlab='Training size (# fields)',ylab='RMSE (t/ha)',type='l',col=cols[3],ylim=ylim,lwd=lwd)
lines(nfields,errbytrainsize[4,],type='l',col=cols[2],lwd=lwd)
lines(nfields,errbytrainsize[6,],type='l',col=cols[1],lwd=lwd)

ylim=c(0,1)

#now use non-full plot train fields to test
oos_rmse2 = function(nfield=20){
  samps = list(sample(1:nrow(mods[[1]]),nfield,replace = F),
               sample(1:nrow(mods[[2]]),nfield,replace = F),sample(1:nrow(mods[[3]]),nfield,replace = F))
  out=c()
  for (modi in 1:3){
    tmpmod = lm(y~.,mods[[modi]][samps[[modi]],])
    trainpts = samps[[1]]
    predy = predict(tmpmod,mods[[1]])[-trainpts]
    truey = mods[[1]][,1][-trainpts]
    perf = c(cor(predy,truey)^2,
             sqrt(mean((predy - truey)^2)))
    out = cbind(out,perf)
  }
  return(out)
}
err2bytrainsize = sapply(nfields,function(x) {
  out=c()
  for (i in 1:nrun) out=rbind(out,as.numeric(oos_rmse2(nfield=x)))
  return(c(apply(out,2,mean),apply(out,2,quantile,.05),apply(out,2,quantile,.95)))})

quartz(w=12,h=5)

#now test on all purestand fields not just big ones
oos_rmse3 = function(nfield=20){
  samps = list(sample(1:nrow(mods[[1]]),nfield,replace = F),
               sample(1:nrow(mods[[2]]),nfield,replace = F),sample(1:nrow(mods[[3]]),nfield,replace = F))
  out=c()
  for (modi in 1:3){
    tmpmod = lm(y~.,mods[[modi]][samps[[modi]],])
    testpts = which(comb$purestand == T)
    predy = predict(tmpmod,comb[testpts,])
    truey = comb$fullplot_yield[testpts]
    perf = c(cor(predy,truey,use='p')^2,
             sqrt(mean((predy - truey)^2,na.rm=T)))
    out = cbind(out,perf)
  }
  return(out)
}
err3bytrainsize = sapply(nfields,function(x) {
  out=c()
  for (i in 1:nrun) out=rbind(out,as.numeric(oos_rmse3(nfield=x)))
  return(c(apply(out,2,mean,na.rm=T),apply(out,2,quantile,.05,na.rm=T),apply(out,2,quantile,.95,na.rm=T)))})

#show both big fields and all purestand fields on same plot
par(mfrow=c(1,2),mar=c(5,5,1,1),cex.lab=1.3,cex.axis=1.3)
cols=brewer.pal(3,'Set1')
ylim=c(0.3,1.5)
lwd=3
plot(nfields,err3bytrainsize[2,],xlab='Training size (# fields)',ylab='RMSE (t/ha)',type='l',col=cols[3],ylim=ylim,lwd=lwd)
grid(lty=1,col=gray(.7))
lines(nfields,err3bytrainsize[4,],type='l',col=cols[2],lwd=lwd)
lines(nfields,err3bytrainsize[6,],type='l',col=cols[1],lwd=lwd)
lines(nfields,err2bytrainsize[2,],type='l',col=cols[3],lwd=lwd,lty=3)
lines(nfields,err2bytrainsize[4,],type='l',col=cols[2],lwd=lwd,lty=3)
lines(nfields,err2bytrainsize[6,],type='l',col=cols[1],lwd=lwd,lty=3)
legend('topright',col=brewer.pal(3,'Set1'),leg=c('SR','CC','FP'),title='Yield source for calibration',bty='y',lwd=2,cex=1.1,bg='white')
legend('bottomleft',col=1,leg=c('All Fields','Fields > 0.1 ha'),bty='y',lwd=2,cex=1.1,lty=c(1,3),bg='white')

ylim=c(0,1)
plot(nfields,err3bytrainsize[1,],xlab='Training size (# fields)',ylab=expression(paste('R'^2)),type='l',col=cols[3],ylim=ylim,lwd=lwd)
grid(lty=1,col=gray(.7))
lines(nfields,err3bytrainsize[3,],type='l',col=cols[2],lwd=lwd)
lines(nfields,err3bytrainsize[5,],type='l',col=cols[1],lwd=lwd)
lines(nfields,err2bytrainsize[1,],type='l',col=cols[3],lwd=lwd,lty=3)
lines(nfields,err2bytrainsize[3,],type='l',col=cols[2],lwd=lwd,lty=3)
lines(nfields,err2bytrainsize[5,],type='l',col=cols[1],lwd=lwd,lty=3)
# legend('topright',col=brewer.pal(3,'Set1'),leg=c('SR','CC','FP'),title='Yield source for calibration',bty='y',lwd=2,cex=1.2,border=NA,bg='white')
# legend('bottomleft',col=1,leg=c('All Fields','Fields > 0.1 ha'),bty='y',lwd=2,cex=1.2,lty=c(1,3),bg='white')
dev.print(png,paste0('rmse_bigandall_bytrainsize.png'),width=1200,height=500)
dev.print(pdf,paste0('rmse_bigandall_bytrainsize.pdf'),width=12,height=5)


#########
#FIG A3 -- calculate sensitivity of agreement to inclusion of certain sow dates
#########
comb$sow_date = ordered(comb$sow_date,levels=c("FEB, 1ST HALF","FEB, 2ND HALF","MARCH, 1ST HALF",
"MARCH, 2ND HALF","APRIL, 1ST HALF","APRIL, 2ND HALF","MAY, 1ST HALF","MAY, 2ND HALF"))
commdates = which(comb$sow_date %in% c("MARCH, 1ST HALF","MARCH, 2ND HALF","APRIL, 1ST HALF","APRIL, 2ND HALF"))
#compare errors as a function of sow dates
boxplot(y <- (satpred1 - fullplot_yield) ~ sow_date,data=comb[commdates,],horizontal=T)
#look at VI correlations with yield for overall dataset vs. fields sown in specific windows
#to address question if we are just picking up sow date effects which are less generalizable
ind=which(comb$plot_area_GPS >= 0.1 & comb$purestand == 1)
yvars = c('sr_yield','cc_yield','fullplot_yield')
xvars = c('DOY_mean_151','DOY_mean_151.2','DOY_mean_171','DOY_mean_171.2')
sowds = c("MARCH, 2ND HALF","APRIL, 1ST HALF","APRIL, 2ND HALF")
corbysowd = function(xvar,yvar,ind) data.frame(allsamp=c(cor(comb[ind,xvar],comb[ind,yvar],use='p'),sum(is.finite(comb[ind,xvar]*comb[ind,yvar]))),
            sapply(sowds,function(i) {
              subi = which(comb$sow_date[ind] == i)
              c(cor(comb[ind[subi],xvar],comb[ind[subi],yvar],use='p'),sum(is.finite(comb[ind[subi],yvar]*comb[ind[subi],xvar])))}))
pd = data.frame()
for (yvar in yvars) for (xvar in xvars){
  pd = rbind(pd,cbind(xvar,yvar,dtype=c('cor','nsamp'),corbysowd(xvar,yvar,ind)))
}
#just display for MTCI
quartz(w=12,h=5)
par(mfrow=c(1,2),mar=c(5,5,1,1),cex.lab=1.3,cex.axis=1.3)
cols=brewer.pal(4,'Set2')
ylim=c(0,.8)
p1 = pd %>% filter(dtype=='cor',xvar %in% c('DOY_mean_151.2'))
barplot(t(as.matrix(p1[,4:7])),col=cols,beside=T,names.arg = yvars,ylab='Correlation',main='Correlation(Yield, MTCI DOY 151)',ylim=ylim)
legend('topleft',fill=cols,leg=c('All','March, 2nd half','April, 1st half','April, 2nd half'),title='Sow Dates')
box()
# p1 = pd %>% filter(dtype=='cor',xvar %in% c('DOY_mean_151'))
# barplot(t(as.matrix(p1[,4:7])),col=cols,beside=T,names.arg = yvars,ylab='Correlation',main='Correlation(Yield, GCVI DOY 151)',ylim=ylim)
# legend('topleft',fill=cols,leg=c('All','March, 2nd half','April, 1st half','April, 2nd half'),title='Sow Dates')
# box()
p1 = pd %>% filter(dtype=='cor',xvar %in% c('DOY_mean_171.2'))
barplot(t(as.matrix(p1[,4:7])),col=cols,beside=T,names.arg = yvars,ylab='Correlation',main='Correlation(Yield, MTCI DOY 171)',ylim=ylim)
legend('topleft',fill=cols,leg=c('All','March, 2nd half','April, 1st half','April, 2nd half'),title='Sow Dates')
box()
# p1 = pd %>% filter(dtype=='cor',xvar %in% c('DOY_mean_171'))
# barplot(t(as.matrix(p1[,4:7])),col=cols,beside=T,names.arg = yvars,ylab='Correlation',main='Correlation(Yield, GCVI DOY 171)',ylim=ylim)
# legend('topleft',fill=cols,leg=c('All','March, 2nd half','April, 1st half','April, 2nd half'),title='Sow Dates')
# box()
dev.print(png,paste0('cor.bysowdate.png'),width=1200,height=500)
dev.print(pdf,paste0('cor.bysowdate.pdf'),width=12,height=5)

#correlation of yields with sow date
cor(as.numeric(comb$sow_date),comb$fullplot_yield,use='p')
ind=which(comb$purestand == 1)
cor(as.numeric(comb$sow_date[ind]),comb$fullplot_yield[ind],use='p')
ind=which(comb$plot_area_GPS >= 0.1 & comb$purestand == 1)
cor(as.numeric(comb$sow_date[ind]),comb$fullplot_yield[ind],use='p')

#regression by sowdate (but much fewer samples)
cor(as.numeric(comb$fullplot_yield[ind]),comb$satpred1[ind],use='p')
ind=which(comb$plot_area_GPS >= 0.1 & comb$purestand == 1 & comb$sow_date <= 'APRIL, 1ST HALF')
cor(as.numeric(comb$fullplot_yield[ind]),comb$satpred1[ind],use='p')
ind=which(comb$plot_area_GPS >= 0.1 & comb$purestand == 1 & comb$sow_date >= 'APRIL, 1ST HALF')
cor(as.numeric(comb$fullplot_yield[ind]),comb$satpred1[ind],use='p')

ind=which(comb$plot_area_GPS >= 0.1 & comb$purestand == 1 & is.finite(comb$fullplot_yield))
labs=table(comb$sow_date[ind]); labs=paste0(names(labs),' (n = ',as.numeric(labs),')')
pd = c()
for (i in levels(comb$sow_date)) {
  tmpind = which(comb$plot_area_GPS >= 0.1 & comb$purestand == 1 & comb$sow_date != i)
  pd = c(pd, cor(comb$fullplot_yield[tmpind],comb$satpred1[tmpind],use='p'))
}

quartz(w=7,h=5)
par(mar=c(5,11,1,1))
a=barplot(rev(pd^2),names=rev(labs),cex.names=.9,horiz = T,xlab=expression(paste('R'^2)),xlim=c(0,1))
basecor = cor(comb$fullplot_yield[ind],comb$satpred1[ind],use='p')
abline(v=basecor^2,lty=2)
box()
dev.print(png,paste0('cor.sens.sowdate.png'),width=700,height=500)
dev.print(pdf,paste0('cor.sens.sowdate.pdf'),width=7,height=5)


#################
#FIGURE A4 -- COMMPARE SKYSAT AND SENTINEL
#################
png('skysat.v.s2.png',w=600,h=500)
#ind=which(comb$plot_area_GPS >= .1 & (comb$purestand == 1))
#use all fields instead of just big ones
ind=which(comb$plot_area_GPS >= .0 & (comb$purestand == 1))
cors = cor(comb[ind,c('fullplot_yield','cc_yield','sr_yield','GCVI_mean','DOY_mean_151','DOY_mean_151.2')],use='p')
cols=brewer.pal(3,'Set1')
barplot(t(cors[3:1,4:6]),beside=T,ylim=c(0,1),names=c('SR yield','CC yield','FP yield'),
        ylab='Correlation with yields',col=cols)
legend('topleft',fill=cols,leg=c('May 29 Skysat GCVI (2m)','May 30 Sentinel-2 GCVI (10m)','May 30 Sentinel-2 MTCI (20m)'),bty='n',text.col=cols)
box()
dev.off()

##compare s2 and skysat on full field and for sub-plot area
#quartz(w=12,h=5)
png('s2.vs.skysat.wholeandsub.png',w=1200,h=500,bg='white')
par(mfrow=c(1,2),mar=c(5,5,3,1))
#ind=which(comb$plot_area_GPS >= .1 & (comb$purestand == 1))
#use all fields instead of just big ones
ind=which(comb$plot_area_GPS >= .1 & (comb$purestand == 1))
cors = cor(comb[ind,c('fullplot_yield','cc_yield','sr_yield','GCVI_mean','DOY_mean_151','DOY_mean_151.2')],use='p')
cols=brewer.pal(3,'Set1')
barplot(t(cors[3:1,4:6]),beside=T,ylim=c(0,1),names=c('SR yield','CC yield','FP yield'),
        ylab='Correlation with yields',col=cols)
legend('topleft',fill=cols,leg=c('May 29 Skysat GCVI (2m)','May 30 Sentinel-2 GCVI (10m)','May 30 Sentinel-2 MTCI (20m)'),bty='n',text.col=cols)
box()
title('VIs averaged over entire field')
cors = cor(subcomb[ind,c('fullplot_yield','cc_yield','sr_yield','GCVI_mean','DOY_mean_151','DOY_mean_151.2')],use='p')
cols=brewer.pal(3,'Set1')
barplot(t(cors[3:1,4:6]),beside=T,ylim=c(0,1),names=c('SR yield','CC yield','FP yield'),
        ylab='Correlation with yields',col=cols)
legend('topleft',fill=cols,leg=c('May 29 Skysat GCVI (2m)','May 30 Sentinel-2 GCVI (10m)','May 30 Sentinel-2 MTCI (20m)'),bty='n',text.col=cols)
box()
title('VIs averaged over 8x8m crop cut area')
dev.off()
# dev.print(png,paste0('s2.vs.skysat.wholeandsub.png'),width=1200,height=500,bg='white')


#################
#FIGURE 6 -- PERFORMANCE ON MIXED FIELDS
#CHANGED TO DO FOR NEW CODING OF PRESENCE/ABSENCE RATHER THAN MAIN
#################
#levels(comb$secondary_crop_cat)[1]='none'
quartz(w=15,h=5)
par(mfrow=c(1,3),mar=c(5,5,1,1))
#levs = list('none','cassava',c('beans','groundnut','other'))
#levs = list('none','cassava',c('beans','groundnut'))

labs = c('(a) Legume intercrop','(b) Cassava intercrop','(c) Both Legume and Cassava')
xlim=ylim=c(0,4)
inds=list(which(comb$intercrop_cassava==0 & comb$intercrop_legume==1),
          which(comb$intercrop_cassava==1 & comb$intercrop_legume==0),
          which(comb$intercrop_cassava==1 & comb$intercrop_legume==1))
seerate_adj = F
for (i in 1:length(inds)){
  x=comb$satpred1[inds[[i]]]
  y=comb$fullplot_yield[inds[[i]]] 
 if (seerate_adj) y=comb$fullplot_yield[inds[[i]]] * 100 / comb$intercrop_seedrate[inds[[i]]]
  ind2 = which(comb$plot_area_GPS[inds[[i]]] >= 0.1)
  plot(x,y,xlab='RS yield',ylab='FP yield',xlim=xlim,ylim=ylim,col=1,pch=1,cex.axis=2,cex.lab=2,cex=1.5)
  abline(c(0,1))
  tempcor = round(cor(x,y,use='p'),2)
  tempn = sum(is.finite(x*y))
  tempcor2 = round(cor(x[ind2],y[ind2],use='p'),2)
  tempn2 = sum(is.finite(x[ind2]*y[ind2]))
  points(x[ind2],y[ind2],col=1,pch=19,cex=1.5)
  #legend('topleft',bty='n',leg=paste0('n = ',tempn,'\nr = ',tempcor),title=labs[i])
  # text(xlim[1]+.1,ylim[2]-.2,labs[i],font=1,pos=4,cex=2.5)
  # text(xlim[2]-1.5,ylim[1]+1,paste0('n = ',tempn, ', r = ',tempcor),font=1,cex=2,pos=4,col=2)
  # text(xlim[2]-1.5,ylim[1]+.7,paste0('n = ',tempn2, ', r = ',tempcor2),font=1,cex=2,pos=4,col=1)
  legend('bottomright',leg=paste0(c('All Fields, r = ','Fields >= 0.1 ha, r = '),c(tempcor,tempcor2)),title = expression(underline("Correlation")),
         text.col=c(1,1),title.adj=0.5,bty='n',xjust=0,inset=.0,cex=1.7)
  if (i==1) legend('right',leg=c(' < 0.1 ha',' >= 0.1 ha'),title=expression(underline('Field Size')),
         pch=c(1,19),bty='y',xjust=0,title.adj=0.5,inset=.02,cex=1.7)
  legend('topleft',bty='n',leg=labs[i],cex=2.5,adj=.1)
#  }
# dif = x-y
  # dens = comb$plant_density[ind]
  # plot(dens,dif,xlab='Maize plant density',ylab='Sat - Fullplot Plot Yield')
  # tempcor3 = round(cor(dens,dif,use='p'),2)
  # legend('topleft',bty='n',leg=paste0('r = ',tempcor3),title=labs[i])
}
if (seerate_adj) {
  dev.print(png,'corr.by.intercrop.seedrateadjusted.png',width=1500,height=500)
} else{
  dev.print(png,'corr.by.intercrop.v2.png',width=1500,height=500)
  dev.print(pdf,'corr.by.intercrop.v2.pdf',width=15,height=5)
}

#################
#FIGURE 7 -- REGRESSION COEFFICIENTS 
#################
#build a full regression model for each output dataset
ps_xvar = c('ln_plot_area_GPS',"ln_dist_plot_gps","cover_crops_present","ln_seedplanted_kg","used_inorganic",
            "ln_hh_labor_days","ln_hiredlabor_days","no_hired_labor",'wave1_SQI',
            "wealthindex","AGmachineindex","dependency_ratio","hhsize",
            "manager_respondent","extension",'femalehead',"head_age","head_yr_ed")
all_xvar = c(ps_xvar,'purestand','ln_intercrop_seedrate')

yieldvars = c('sr_yield','cc_yield','fullplot_yield','satpred1','satpred2','scymyield')
psregs=list()
ind = which((comb$purestand == 1))
for (y.i in yieldvars) psregs[[y.i]] = (lm(comb[ind,y.i] ~ as.matrix(comb[ind,ps_xvar])))
allfieldsregs = list()
ind = which((comb$purestand <= 1))
for (y.i in yieldvars) allfieldsregs[[y.i]] = (lm(comb[ind,y.i] ~ as.matrix(comb[ind,all_xvar])))
panelonlyregs = list()
ind = which(comb$parcel_panel == 1)
for (y.i in yieldvars) panelonlyregs[[y.i]] = (lm(comb[ind,y.i] ~ as.matrix(comb[ind,all_xvar])))


var.to.plot = c('ln_plot_area_GPS','wave1_SQI',"used_inorganic")
coef.pos = c(2,10,6)
coef.names = c('Log(plot area)','Soil Quality Index','Used Fertilizer')
coef.names = c('Plot area','Soil Quality','Fertilizer')
pd1 = lapply(psregs,function(x) summary(x)$coef[coef.pos,])
pd2 = lapply(allfieldsregs,function(x) summary(x)$coef[coef.pos,])
pd3 = lapply(panelonlyregs,function(x) summary(x)$coef[coef.pos,])

makeplot = function(pd,ylim=c(-5,8),ylab='Regression Coefficient'){
  mids = t(sapply(pd,function(x) x[,1]))
  lows = mids - 2* t(sapply(pd,function(x) x[,2]))
  his = mids + 2* t(sapply(pd,function(x) x[,2]))
  a=barplot(mids,beside=T,plot=F)
  nmod=nrow(mids)
  cols=c(brewer.pal(3,'Set1'),grey(seq(.3,.7,length.out=nmod-3)))
  plot(a,mids,col=cols,ylim=ylim,ylab=ylab,xlab='',axes=F)
  axis(2)
  axis(1,at=a[3,],labels = coef.names)
  box()
  abline(v=a[nmod,]+1)
  for (i in 1:length(a)) arrows(a[i],lows[i],a[i],his[i],length=.1,angle=90,code=3,col=rep(cols,10)[i])
  abline(h=0)
  legend('topright',leg=c('SR','CC','FP','RS_CAL_FP','RS_CAL_CC','RS_SCYM'),text.col=cols,bty='n',title='Yield source',title.col=1)
}

quartz(w=12,h=5)
par(mfrow=c(1,2),lwd=3,mar=c(5,4,1,1))
makeplot(pd1)
legend('topleft',leg='(a) Purestand',bty='n')
makeplot(pd2)
legend('topleft',leg='(b) All fields',bty='n')
dev.print(png,'reg.coef.png',width=1200,height=500)
dev.print(pdf,'reg.coef.pdf',width=12,height=5)
out = rbind(data.frame(subs='all fields',pd2),data.frame(subs='purestand fields',pd1))
write.csv(out,file='regplot.csv',row.names=T)
#if want to compare to limiting to only parcel panel plots
#makeplot(pd3)

#a version that uses logs of kg/ha instead (drops points with yield of 0)
logpsregs=list()
ind = which((comb$purestand == 1))
for (y.i in yieldvars) logpsregs[[y.i]] = (lm(log(1e3*comb[ind,y.i]) ~ as.matrix(comb[ind,ps_xvar]),subset=which(comb[ind,y.i]>0)))
logallfieldsregs = list()
ind = which((comb$purestand <= 1))
for (y.i in yieldvars) logallfieldsregs[[y.i]] = (lm(log(1e3*comb[ind,y.i]) ~ as.matrix(comb[ind,all_xvar]),subset=which(comb[ind,y.i]>0)))

logpd1 = lapply(logpsregs,function(x) summary(x)$coef[coef.pos,])
logpd2 = lapply(logallfieldsregs,function(x) summary(x)$coef[coef.pos,])

par(mfrow=c(1,2),lwd=3,mar=c(5,4,1,1))
makeplot(logpd1,ylim=c(-1,5))
legend('topleft',leg='(a) Purestand',bty='n')
makeplot(logpd2,ylim=c(-1,5))
legend('topleft',leg='(b) All fields',bty='n')
dev.print(png,'reg.logcoef.png',width=1200,height=500)
dev.print(pdf,'reg.logcoef.pdf',width=12,height=5)

#use stargazer package to write full results out
require(stargazer)
xlabs = substr(gsub('[.]','_',ps_xvar),1,15)
xlabs = gsub('_','',xlabs)
temp = stargazer(psregs,title='Results',align=T,
                 out='psregs.txt',column.labels = yieldvars,dep.var.labels.include = F, digits=2,
                 covariate.labels = xlabs,single.row=T)
xlabs = substr(gsub('[.]','_',all_xvar),1,15)
xlabs = gsub('_','',xlabs)
temp = stargazer(allfieldsregs,title='Results',align=T,
                 out='allfieldregs.txt',column.labels = yieldvars,dep.var.labels.include = F, digits=2,
                 covariate.labels = xlabs,single.row=T)

